# Release history

### 1.1.0
* Create a dedicated lambda function to generate 
  api keys. You should not interact with the database directly. 
  
### 1.0.0
* Prod-ready version.
* Added documentation.
* Added more tests.
* Some code improvements.

### 0.1.0
* Initial testing done. Authorizer works.
* Need more tests and edge case handling before promoting to 1.0.0.

### 0.0.1
* Initial build.
